import React, { useEffect, useRef } from 'react';
import * as d3 from 'd3';

export interface ScatterplotProps {
  data: { x: number; y: number }[];
}

const Scatterplot: React.FC<ScatterplotProps> = ({ data }) => {
  const svgRef = useRef<SVGSVGElement | null>(null);

  useEffect(() => {
    if (svgRef.current) {
      const svg = d3.select(svgRef.current);

      svg
        .selectAll('circle')
        .data(data)
        .enter()
        .append('circle')
        .attr('cx', (d) => d.x * 30)
        .attr('cy', (d) => 100 - d.y * 10)
        .attr('r', 5)
        .attr('fill', 'red');
    }
  }, [data]);

  return (
    <div>
      <h2>Scatterplot</h2>
      <svg ref={svgRef} width={300} height={120}></svg>
    </div>
  );
};

export default Scatterplot;
