import { Meta } from '@storybook/react';

import { configureStore } from '@reduxjs/toolkit';
import { Provider } from 'react-redux';
import { big2ndChamberQueryResult, smallFlightsQueryResults, mockLargeQueryResults } from '../../../mock-data';

import {
  setNewGraphQueryResult,
  graphQueryResultSlice,
  querybuilderSlice,
  schemaSlice,
  setSchema,
  visualizationSlice,
} from '../../../data-access/store';

import { SchemaUtils } from '../../../schema/schema-utils';
import { simpleSchemaAirportRaw } from '../../../mock-data/schema/simpleAirportRaw';
import { setActiveVisualization } from '@graphpolaris/shared/lib/data-access/store/visualizationSlice';
import MatrixVisComponent from './matrixvis';

const Component: Meta<typeof MatrixVisComponent.component> = {
  title: 'Visualizations/MatrixVis',
  component: MatrixVisComponent.component,
  decorators: [
    (story) => (
      <Provider store={Mockstore}>
        <div
          style={{
            width: '100%',
            height: '100vh',
          }}
        >
          {story()}
        </div>
      </Provider>
    ),
  ],
};

const Mockstore: any = configureStore({
  reducer: {
    schema: schemaSlice.reducer,
    graphQueryResult: graphQueryResultSlice.reducer,
    visualize: visualizationSlice.reducer,
    querybuilder: querybuilderSlice.reducer,
  },
});

export const TestWithData = {
  layout: 'fullscreen',
  args: {
    data: {
      nodes: [
        { id: 'agent/007', attributes: { name: 'Daniel Craig' } },
        { id: 'villain', attributes: { name: 'Le Chiffre' } },
      ],
      edges: [{ id: 'escape/escape', from: 'agent/007', to: 'villain', attributes: { name: 'Escape' } }],
    },
    ml: {},
    configuration: MatrixVisComponent.configuration,
  },
  play: async () => {
    // const dispatch = Mockstore.dispatch;
    // const schema = SchemaUtils.schemaBackend2Graphology(simpleSchemaAirportRaw);
    // dispatch(setSchema(schema.export()));
  },
};

export const TestWithNoData = {
  args: {
    data: {
      nodes: [],
      edges: [],
    },
    ml: {},
    configuration: MatrixVisComponent.configuration,
  },
};

export const TestWithBig2ndChamber = {
  args: {
    data: big2ndChamberQueryResult,
    ml: {},
    configuration: MatrixVisComponent.configuration,
  },
};

export const TestWithSmallFlights = {
  args: {
    data: smallFlightsQueryResults,
    ml: {},
    configuration: MatrixVisComponent.configuration,
  },
};

export const TestWithLargeQueryResult = {
  args: {
    data: mockLargeQueryResults,
    ml: {},
    configuration: MatrixVisComponent.configuration,
  },
};

export default Component;
